.. _tutorials:

Tutorials
=========

See the following IPython Notebooks for some examples of using `qp`:

* `Basic Demo <http://htmlpreview.github.io/?https://github.com/LSSTDESC/qp/blob/docs/demo.html>`_
* `Practical Example <http://htmlpreview.github.io/?https://github.com/LSSTDESC/qp/blob/docs/practical_example.html>`_
